@@ -1,12 +1,29 @@
+ # Copyright (C) 2010 Oscar Perpiñán Lamigueiro
+ #
+ # This program is free software; you can redistribute it and/or
+ # modify it under the terms of the GNU General Public License
+ # as published by the Free Software Foundation; either version 2
+ # of the License, or (at your option) any later version.
+ #
+ # This program is distributed in the hope that it will be useful,
+ # but WITHOUT ANY WARRANTY; without even the implied warranty of
+ # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ # GNU General Public License for more details.
+ #
+ # You should have received a copy of the GNU General Public License
+ # along with this program; if not, write to the Free Software
+ # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ #/
 setOldClass('zoo')
 setOldClass('loess')
+setOldClass('difftime')
 
 setClass(
-         Class='Meteo', ##datos diarios de radiación y temperatura
+         Class='Meteo', ##datos de radiación y temperatura
          representation=representation(
            latData='numeric',       #latitud, en grados, >0 si Norte
            data='zoo',          #datos, incluyendo G (Wh/m2) y Ta (ºC)
-           type='character',    #a elegir entre 'prom', 'bd', 'mapa'
+           type='character',    #a elegir entre 'prom', 'bd', 'mapa', 'bdI'
            source='character' #información sobre el origen de los datos
            ),
          validity=function(object) {return(TRUE)}
@@ -19,7 +36,7 @@ setClass(
            solD='zoo',                #angulos diarios
            solI='zoo',                #angulos intradiarios
            match='numeric', #indices de solD que coinciden con días de solI
-           sample='character'
+           sample='difftime'
            ),
          validity=function(object) {return(TRUE)}
          )
@@ -32,7 +49,7 @@ setClass(
            G0y='zoo',                #aggregate, valores anuales
            G0I='zoo',                #resultado de fCompI
            Ta='zoo'),                 #Temperatura ambiente intradiaria
-         ##		sample='character'#según lo pasado a fSolI
+         ##             sample='difftime'#según lo pasado a fSolI
          contains=c('Meteo','Sol'),
          validity=function(object) {
            return(TRUE)}
@@ -68,7 +85,7 @@ setClass(
            module='list',
            generator='list',
            inverter='list',
-           effSys='list'		
+           effSys='list'
            ),
          contains='Gef',
          validity=function(object) {return(TRUE)}
@@ -85,7 +102,7 @@ setClass(
            H='numeric',
            pump='list',
            converter='list',
-           effSys='list'		
+           effSys='list'
            ),
          contains='Gef',
          validity=function(object) {return(TRUE)}
