@@ -1,22 +1,20 @@
-#    fInclin: calculo de radiación en el plano inclinado
-#    Copyright (c) 2009-2010, Oscar Perpiñán. Lamigueiro
-
-#    Este programa es software libre: usted puede redistribuirlo y/o modificarlo 
-#    bajo los términos de la Licencia Pública General GNU publicada 
-#    por la Fundación para el Software Libre, ya sea la versión 3 
-#    de la Licencia, o (a su elección) cualquier versión posterior.
-
-#    Este programa se distribuye con la esperanza de que sea útil, pero 
-#    SIN GARANTÍA ALGUNA; ni siquiera la garantía implícita 
-#    MERCANTIL o de APTITUD PARA UN PROPÓSITO DETERMINADO. 
-#    Consulte los detalles de la Licencia Pública General GNU para obtener 
-#    una información más detallada. 
-
-#    Debería haber recibido una copia de la Licencia Pública General GNU 
-#    junto a este programa. 
-#    En caso contrario, consulte <http://www.gnu.org/licenses/>.
-#-------------------------------------------------------------------------------
-fInclin<-function(compI, angGen, iS=2, alb=0.2){
+ # Copyright (C) 2009, 2010 Oscar Perpiñán Lamigueiro
+ #
+ # This program is free software; you can redistribute it and/or
+ # modify it under the terms of the GNU General Public License
+ # as published by the Free Software Foundation; either version 2
+ # of the License, or (at your option) any later version.
+ #
+ # This program is distributed in the hope that it will be useful,
+ # but WITHOUT ANY WARRANTY; without even the implied warranty of
+ # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ # GNU General Public License for more details.
+ #
+ # You should have received a copy of the GNU General Public License
+ # along with this program; if not, write to the Free Software
+ # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ #/
+fInclin<-function(compI, angGen, iS=2, alb=0.2, horizBright=FALSE){
   ##compI es class='G0'
   ##angGen es 'zoo', resultado de fTheta
 
@@ -43,7 +41,8 @@ fInclin<-function(compI, angGen, iS=2, alb=0.2){
 ###Metodo Hay and Davies para tratamiento difusa
   B=B0*cosTheta/cosThzS*(cosThzS>0.007); #El factor cosThzS>0.007 hace falta para eliminar resultados erroneos cerca del amanecer
   k1=B0/(Bo0);
-  Di=D0*(1-k1)*(1+cos(Beta))/2;  
+  factor=1+sqrt(B0/G0)*sin(Beta/2)^3
+  Di=D0*(1-k1)*(1+cos(Beta))/2*(horizBright*factor);  
   Dc=D0*k1*cosTheta/cosThzS*(cosThzS>0.007);
   R=alb*G0*(1-cos(Beta))/2;
   D=(Di+Dc);
