@@ -1,21 +1,19 @@
-#    fTheta: calculo de ángulos en un receptor solar
-#    Copyright (c) 2009-2010, Oscar Perpiñán. Lamigueiro
-
-#    Este programa es software libre: usted puede redistribuirlo y/o modificarlo 
-#    bajo los términos de la Licencia Pública General GNU publicada 
-#    por la Fundación para el Software Libre, ya sea la versión 3 
-#    de la Licencia, o (a su elección) cualquier versión posterior.
-
-#    Este programa se distribuye con la esperanza de que sea útil, pero 
-#    SIN GARANTÍA ALGUNA; ni siquiera la garantía implícita 
-#    MERCANTIL o de APTITUD PARA UN PROPÓSITO DETERMINADO. 
-#    Consulte los detalles de la Licencia Pública General GNU para obtener 
-#    una información más detallada. 
-
-#    Debería haber recibido una copia de la Licencia Pública General GNU 
-#    junto a este programa. 
-#    En caso contrario, consulte <http://www.gnu.org/licenses/>.
-#-------------------------------------------------------------------------------
+ # Copyright (C) 2009, 2010 Oscar Perpiñán Lamigueiro
+ #
+ # This program is free software; you can redistribute it and/or
+ # modify it under the terms of the GNU General Public License
+ # as published by the Free Software Foundation; either version 2
+ # of the License, or (at your option) any later version.
+ #
+ # This program is distributed in the hope that it will be useful,
+ # but WITHOUT ANY WARRANTY; without even the implied warranty of
+ # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ # GNU General Public License for more details.
+ #
+ # You should have received a copy of the GNU General Public License
+ # along with this program; if not, write to the Free Software
+ # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ #/
 fTheta<-function(sol, beta, alfa=0, modeTrk='fixed', betaLim=90, 
                  BT=FALSE, struct, dist){
 
@@ -80,7 +78,7 @@ fTheta<-function(sol, beta, alfa=0, modeTrk='fixed', betaLim=90,
                      cosTheta
                    }
                    );
-  cosTheta[!aman]<-NA;
+  is.na(cosTheta) <- (!aman)
   cosTheta=cosTheta*(cosTheta>0); #cuando cosTheta<0, Theta es mayor de 90º, y por tanto el Sol está detras del panel.
     
   result<-zoo(data.frame(Beta, Alfa, cosTheta), order.by=indexI(sol))   
